import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { Button, Stack, Text } from '@chakra-ui/react';
import { saveNetworkStatus } from '../save-network-status.js';
import { useContainer } from '../hooks/use-container.js';
import { useNetworkStatus } from '../hooks/use-network-status.js';
import { useCurrentStatus } from '../hooks/use-current-status.js';
/**
 * React component that manages network state.
 * @param {DeepClient} deep - The DeepClient object instance.
 * @param {number} containerLinkId - The container link id to store network status.
 */
export function NetworkStatus({ deep, containerLinkId: passedContainerLinkId }) {
    const containerLinkIdFromHook = useContainer(deep);
    const [containerLinkId, setContainerLinkId] = useState(passedContainerLinkId || containerLinkIdFromHook);
    useEffect(() => {
        setContainerLinkId(passedContainerLinkId || containerLinkIdFromHook);
    }, [deep, passedContainerLinkId, containerLinkIdFromHook]);
    const { connectionStatuses, subscribeToNetworkStatusChanges } = useNetworkStatus({ deep, containerLinkId });
    const { currentStatus, loadCurrentStatus } = useCurrentStatus({ deep, containerLinkId });
    return (_jsxs(Stack, { alignItems: "center", children: [_jsx(Text, { size: "lg", children: "NETWORK STATE" }), _jsx(Button, { onClick: async () => { await subscribeToNetworkStatusChanges(); }, children: _jsx(Text, { children: "SUBSCRIBE" }) }), _jsx(Button, { onClick: async () => await saveNetworkStatus({ deep, containerLinkId, connectionStatuses: [] }), children: _jsx(Text, { children: "SAVE CURRENT" }) }), _jsx(Button, { onClick: async () => loadCurrentStatus(), children: _jsx(Text, { children: "GET CURRENT" }) }), currentStatus ? (_jsxs(Stack, { direction: "row", children: [_jsx(Text, { children: "CURRENT:" }), _jsx(Text, { children: currentStatus })] }))
                : null] }));
}
